@@ -52,7 +52,7 @@ class App(RedisMixin, LoggingMixin, RollbarMixin):
         end_time = event[-1].get("timestamp")
         system_time = time.time()
 
-        self.log(
+        self.debug(
             self.asset_id,
             "Received {} elements from {} to {} at {}. {} seconds of initial data are lookback.".format(
                 batch_size, start_time, end_time, system_time, max_lookback_seconds
